Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1472)

Unified Diff: pnacl/build.sh

Issue 9979025: [MIPS] Adding validator for MIPS architecture. (Closed) Base URL: http://src.chromium.org/native_client/trunk/src/native_client/
Patch Set: Changes after second code review. Created 8 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pnacl/build.sh
diff --git a/pnacl/build.sh b/pnacl/build.sh
index 3ac2a91253e5e2a3d9deb7c161ed8c9b0904bb8d..d97f1f61b7bf5f064250405c28a04927eefc98cb 100755
--- a/pnacl/build.sh
+++ b/pnacl/build.sh
@@ -46,10 +46,12 @@ readonly PNACL_CONCURRENCY=${PNACL_CONCURRENCY:-8}
readonly PNACL_MERGE_TESTING=${PNACL_MERGE_TESTING:-false}
PNACL_PRUNE=${PNACL_PRUNE:-false}
PNACL_BUILD_ARM=true
+# PNACL_BUILD_MIPS=true
Nick Bray (chromium) 2012/04/27 19:41:33 Nit: I haven't ever looked at this script before,
if ${BUILD_PLATFORM_MAC} || ${BUILD_PLATFORM_WIN}; then
# We don't yet support building ARM tools for mac or windows.
PNACL_BUILD_ARM=false
+ PNACL_BUILD_MIPS=false
fi
readonly SB_JIT=${SB_JIT:-false}
@@ -1822,6 +1824,21 @@ arm-ncval-core ${INSTALL_ROOT}/tools-x86
else
StepBanner "MISC-ARM" "Skipping ARM validator (Not yet supported on Mac)"
fi
+
+ if ${BUILD_PLATFORM_LINUX} ; then
+ StepBanner "MISC-MIPS" "Building validator (MIPS32)"
+ spushd "${NACL_ROOT}"
+ RunWithLog mips_ncval_core \
+ ./scons MODE=opt-host \
+ targetplatform=mips32 \
+ sysinfo=0 \
+ mips-ncval-core
+ cp scons-out/opt-linux-x86-32-to-mips32/obj/src/trusted/validator_mips/\
+mips-ncval-core ${INSTALL_ROOT}/tools-x86/mips-ncval-core
+ spopd
+ else
+ StepBanner "MISC-MIPS" "Skipping MIPS validator (Not yet supported on Mac)"
+ fi
}
#########################################################################
@@ -46,10 +46,12 @@ readonly PNACL_CONCURRENCY=${PNACL_CONCURRENCY:-8}
Nick Bray (chromium) 2012/04/27 19:41:33 Nit: I haven't ever looked at this script before,
if ${BUILD_PLATFORM_MAC} || ${BUILD_PLATFORM_WIN}; then
- # We don't yet support building ARM tools for mac or windows.
+ # We don't yet support building ARM and MIPS tools for mac or windows.
PNACL_BUILD_ARM=false

Powered by Google App Engine
This is Rietveld 408576698